Instruments (``taurex.instruments``)
====================================

Base
-------------------------

.. automodule:: taurex.instruments.instrument
   :members:
   :undoc-members:
   :show-inheritance:


Signal-to-Noise
-------------------------

.. automodule:: taurex.instruments.snr
   :members:
   :undoc-members:
   :show-inheritance:
